# WechatPush

![Language](https://img.shields.io/badge/Language-Python-yellow)![LICENSE](https://img.shields.io/badge/LICENSE-MIT-red)![Author](https://img.shields.io/badge/Author-DanKe-blue)

# 官方文档：http://wechatpush.danke.ml

Python微信公众号/订阅号/测试号推送库

功能目前还不完善，将逐步完善微信推送所有功能

